@@ -8,10 +8,11 @@ use List::MoreUtils qw/zip/;
 use Data::Dumper;
 use Storable qw(dclone);
 use Scalar::Util qw/refaddr/;
+use Bio::Gonzales::Seq::Util qw/strand_convert/;
 
 our $QUIET_MODE;
 
-our $VERSION = '0.0548'; # VERSION
+our $VERSION = '0.0549'; # VERSION
 
 extends 'Bio::Gonzales::MiniFeat';
 
@@ -19,23 +20,23 @@ has [qw/seq_id start end strand/] => ( is => 'rw', required => 1 );
 
 has [qw/phase score /] => ( is => 'rw' );
 
-
 sub scf_id { return shift->seq_id(@_); }
 
 sub length { return $_[0]->end - $_[0]->start + 1 }
 
 sub begin { return shift->start(@_) }
 
-our %STRAND_CHAR_TABLE = (
-  '+' => 1,
-  '-' => -1,
-  '.' => 0,
-  -1  => '-',
-  1   => '+',
-  0   => '.',
-);
+sub Convert_strand { strand_convert(@_) }
 
-sub Convert_strand { return $STRAND_CHAR_TABLE{ $_[-1] } }
+sub switch_coords {
+  my $self = shift;
+
+  my ($b, $e) = ($self->start, $self->end);
+  $self->start($e);
+  $self->end($b);
+
+  return $self;
+}
 
 
 sub sort_subfeats {
