@@ -9,7 +9,7 @@ use Data::Dumper;
 
 use base 'Exporter';
 our ( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
-our $VERSION = '0.0548'; # VERSION
+our $VERSION = '0.0549'; # VERSION
 
 @EXPORT      = qw();
 %EXPORT_TAGS = ();
@@ -22,8 +22,26 @@ our $VERSION = '0.0548'; # VERSION
   map_seqids
   seqid_mapper
   crc64
+  strand_convert
 );
 
+our %STRAND_CHAR_TABLE = (
+  '+' => 1,
+  '-' => -1,
+  '.' => 0,
+  -1  => '-',
+  1   => '+',
+  0   => '.',
+);
+
+sub strand_convert {
+  if ( @_ && @_ > 0 && $_[-1] && exists( $STRAND_CHAR_TABLE{ $_[-1] } ) ) {
+    return $STRAND_CHAR_TABLE{ $_[-1] };
+  } else {
+    return '.';
+  }
+}
+
 sub pairwise_identity_l {
   my ( $seq1, $seq2 ) = @_;
   return _pairwise_identity_generic( $seq1, $seq2, 1, 0 );
